//arcgisserver api
import WebTileLayer from "esri/layers/WebTileLayer";
import TileInfo from "esri/layers/support/TileInfo";
import SpatialReference from "esri/geometry/SpatialReference";
import MapImageLayer from "esri/layers/MapImageLayer";
import BaseTileLayer from "esri/layers/BaseTileLayer";
import esriRequest from "esri/request";
import FeatureLayer from "esri/layers/FeatureLayer";
//工具类
import {
    validate,
    validateParas,
    get as getConfig,
    getConfigParas
} from "./baseLayerSetting";

// 主要是创建底图的配置
// 创建天地图图层 _arcgisserver
function createTDT_VectorLayer (config) {
    let tiandituBaseUrl = "http://{subDomain}.tianditu.gov.cn"; //天地图服务地址
    let token = "174705aebfe31b79b3587279e211cb9a"; //天地图token
    let highlight;
    //矢量地图(球面墨卡托投影)
    let tiledLayer = new WebTileLayer({
        urlTemplate:
            tiandituBaseUrl + "/vec_w/wmts?SERVICE=WMTS&VERSION=1.0.0&REQUEST=GetTile&LAYER=vec&STYLE=default&FORMAT=tiles&TILEMATRIXSET=w&TILEMATRIX={level}&TILEROW={row}&TILECOL={col}&tk=" + token,
        subDomains:
            ["t0", "t1", "t2", "t3", "t4", "t5", "t6", "t7"]
    });
    //矢量注记(球面墨卡托投影)
    let tiledLayerAnno = new WebTileLayer({
        title: "TDT_Vector",
        urlTemplate:
            tiandituBaseUrl + "/cva_w/wmts?SERVICE=WMTS&VERSION=1.0.0&REQUEST=GetTile&LAYER=cva&STYLE=default&FORMAT=tiles&TILEMATRIXSET=w&TILEMATRIX={level}&TILEROW={row}&TILECOL={col}&tk=" + token,
        subDomains:
            ["t0", "t1", "t2", "t3", "t4", "t5", "t6", "t7"]
    });

    return [tiledLayer, tiledLayerAnno]
}


// 创建超图的底图
function createSupermap (config) {
    let tileInfo = new TileInfo({
        "dpi": 96,
        "format": "image/png",
        "compressionQuality": 0,
        "spatialReference": new SpatialReference(4326),
        "rows": 256,
        "cols": 256,
        "origin": {
            "x": -180,
            "y": 90
        },
        "lods": [
            { "level": "0", "scale": 295829355.45, "resolution": 0.703125 },
            { "level": "1", "scale": 147914677.725, "resolution": 0.3515625 },
            { "level": "2", "scale": 73957338.8625, "resolution": 0.17578125 },
            { "level": "3", "scale": 36978669.43125, "resolution": 0.087890625 },
            { "level": "4", "scale": 18489334.715625, "resolution": 0.0439453125 },
            { "level": "5", "scale": 9244667.3578125, "resolution": 0.02197265625 },
            { "level": "6", "scale": 4622333.67890625, "resolution": 0.010986328125 },
            { "level": "7", "scale": 2311166.83945312, "resolution": 0.0054931640625 },
            { "level": "8", "scale": 1155583.41972656, "resolution": 0.00274658203125 },
            { "level": "9", "scale": 577791.709863281, "resolution": 0.001373291015625 },
            { "level": "10", "scale": 288895.8549316406, "resolution": 6.866455078125E-4 },
            { "level": "11", "scale": 144447.9274658203, "resolution": 3.4332275390625E-4 },
            { "level": "12", "scale": 4508.935440959931, "resolution": 1.71661376953125E-4 },
            { "level": "13", "scale": 36111.98186645508, "resolution": 8.58306884765625E-5 },
            { "level": "14", "scale": 18055.99093322754, "resolution": 4.291534423828125E-5 },
            { "level": "15", "scale": 9027.99546661377, "resolution": 2.1457672119140625E-5 },
            { "level": "16", "scale": 4513.997733306885, "resolution": 1.0728836059570312E-5 },
            { "level": "17", "scale": 2256.9988666534423, "resolution": 5.364418029785156E-6 },
            { "level": "18", "scale": 1128.4994333267211, "resolution": 2.682209014892578E-6 },
            { "level": "19", "scale": 564.2497166633606, "resolution": 1.341104507446289E-6 }
        ]
    });

    let layer = new WebTileLayer(
        {
            // urlTemplate:"http://jgsw.gy.wodcloud.com/iserver/services/map-guizhou/wmts-china/guizhou/default/ChinaPublicServices_guizhou/{level}/{row}/{col}.png",
            urlTemplate: "http://jgsw.gy.wodcloud.com/iserver/services/map-guizhou/wmts-china?SERVICE=WMTS&VERSION=1.0.0&REQUEST=GetTile&LAYER=guizhou&STYLE=default&FORMAT=image/png&TILEMATRIXSET=ChinaPublicServices_guizhou&tileMatrix={level}&tileRow={row}&tileCol={col}",
            tileInfo: tileInfo,
            spatialReference: new SpatialReference(4326),
        }

    );
    return layer
}

//创建arcgisServer的mapserver底图
function createArcgisMapserver (config, url) {
    let mapserverUrl = ""
    if ("" != url && null != url) {
        mapserverUrl = url;
    } else {
        mapserverUrl = config.server

    }
    let mapLayer = new MapImageLayer({
        url: mapserverUrl
    });
    console.log("打印mapserverUrl");
    console.log(mapserverUrl);
    return mapLayer
}

//创建arcgisServer的服务图层
function createArcgisServerWMTS (config) {
    console.log(config);
}

//创建高德的图层
function createAmap (config) {
    let initGDLayer = BaseTileLayer.createSubclass({
        title: "Amap_title",
        properties: {
            urlTemplate: null,
        },
        getTileUrl: function (level, row, col) {
            return 'http://webrd0' + (col % 4 + 1) + '.is.autonavi.com/appmaptile?lang=zh_cn&size=1&scale=1&style=8&x=' + col + '&y=' + row + '&z=' + level;
        },
        fetchTile: function (level, row, col) {
            let url = this.getTileUrl(level, row, col);
            return esriRequest(url, {
                responseType: "image"
            })
                .then(function (response) {
                    let image = response.data;
                    let width = this.tileInfo.size[0];
                    let height = this.tileInfo.size[0];
                    let canvas = document.createElement("canvas");
                    let context = canvas.getContext("2d");
                    canvas.width = width;
                    canvas.height = height;
                    context.drawImage(image, 0, 0, width, height);
                    return canvas;
                }.bind(this));
        }
    })
    let gaodeLayer = new initGDLayer();
    return gaodeLayer;
}

export function createLayer (key = "Amap", url = "") {
    if (!validate(key)) {
        return null;
    }
    let config = getConfig(key);
    let layer = null;
    switch (key) {
        // Google和高德的方式相同
        case "Google":
        case "Amap":
            layer = createAmap(config)
            break;
        case "TDTVector":
            layer = createTDT_VectorLayer(config);
            break;
        case "TDTImage":
            layer = createTDTImageLayer(config);
            break;
        case "ArcgisServerWMTS":
            layer = createArcgisServerWMTS(config);
            break;
        case "SuperMap":
            layer = createSupermap(config);
        case "ArcgisMapServer":
            layer = createArcgisMapserver(config, url);
    }
    return layer;
}

export function createLayers (paras = [{ type: "OSM", URL: "" }]) {
    if (!validateParas(paras)) {
        return null;
    }
    const configParas = getConfigParas(paras);
    let layers = [];
    console.log(configParas + layers);
}
