/**
 * 主题图层配置
 */
const LAYERS = {
    HeatMap: {
        server: null,   //地址（暂时未配置）
        url: "https://apaasgis.wodcloud.com/server/rest/services/GZ_JTQJ/MapServer/11",
        preview: require("../../static/arcImage/maptype/OSM.png"),   //热力图的图标（到时候可以做图层控制）
        visible: true,
        title: "HeatMap",
        id: "heatmaplayer",
        outFields: ["*"],
        legendEnabled: true,
        center: [0, 0],
        maxScale: 1000,
        minScale: 7000000,
        definitionExpression: "",
        renderer: {
            type: "heatmap",
            //field: "total_coun", //热力点的权值字段，如果为空则每个热力点自身权重一样
            blurRadius: 10, //热力点的影响范围单位px，超过此范围的按权值按0计算
            //颜色区间，变化范围，ratio = 热力点的权值/maxPixelIntensity
            colorStops: [
                {
                    ratio: 0,
                    color: "rgba(0, 0, 255, 0)"
                },
                {
                    ratio: 0.1,
                    color: "royalblue"
                },
                {
                    ratio: 0.3,
                    color: "cyan"
                },
                {
                    ratio: 0.5,
                    color: "lime"
                },
                {
                    ratio: 0.7,
                    color: "yellow"
                },
                {
                    ratio: 1,
                    color: "red"
                }
            ],
            //像素点的最高权值，当其权值超过100时，按100计算
            maxPixelIntensity: 15,
            minPixelIntensity: 0
        }
    },
    MigrateLayer: {
        title: "迁徙图",
        server: "",
        preview: require("../../static/arcImage/maptype/Founder.png")
    },
    ClusterLayer: {
        title: "聚合图",
        server: "",
        preview: require("../../static/arcImage/maptype/Founder.png")
    },
};

// 验证配置的名称是否存在
export function validate (key) {
    const keys = Object.keys(LAYERS);
    const valid = keys.includes(key);
    if (!valid) {
        throw new Error(`主题图层配置 ${key} 不存在`);
    }
    return valid;
}

export function set (layers) {
    Object.keys(layers).forEach(key => {
        const layer = layers[key];
        Object.assign(LAYERS[key], layer);
    });
}

/**
 * 获取图层服务配置
 * @param {String} [key=null] 图层名称,为null时表示获取全部图层配置
 * @param {boolean} [toArray=false] 是否转换成数组
 * @return {Object|Array}
 */
export function get (key = null, toArray = false) {
    if (key && validate(key)) {
        return LAYERS[key];
    }
    if (!toArray) {
        return LAYERS;
    }
    return Object.keys(LAYERS).map(key => {
        return {
            name: key,
            ...LAYERS[key]
        };
    });
}

export function validateParas () { }
export function getConfigParas () { }
