
const BASE_TYPES = [Array, String, Boolean, Object, Function];

/**
 * 合并组件的props
 * @return {any}
 */
export function mixProps () {
    const propsArray = Array.from(arguments).map(item => item.props || {});
    const props = Object.assign({}, ...propsArray);
    const fixedProps = Object.create(null);
    Object.entries(props).forEach(item => {
        const key = item[0];
        fixedProps[key] = BASE_TYPES.includes(item[1])
            ? { type: item[1] }
            : item[1];
    });
    return fixedProps;
}

/**
 * 获取组件的父级的地图组件
 * @return {*|Vue}
 */
export function getParent () {
    console.log("获取父组件");
    let parent = this.$parent;
    while (parent && !parent.isMap) {
        parent = parent.$parent;
    }
    console.log("获取父组件完成");
    return parent;
}

/**
 * 地图初始化完成回调
 * @param callback
 */
export function viewReady (callback) {
    console.log("开始监听父组件的状态");
    // 先检查父组件的地图是否初始化完成
    if (this.parent && this.parent.map) {
        callback(this.parent.map, this.parent);
        console.log("开始监听父组件完成");
        return;
    }
    // 父组件地图未初始化，侦听完成事件
    this.parent.$once("ready", (map, vm) => {
        callback(map, vm);
    });
}


